## 基金经理

接口：fund_manager

描述：获取公募基金经理数据，包括基金经理简历等数据

限量：单次最大5000，支持分页提取数据

积分：用户有500积分可获取数据，2000积分以上可以提高访问频次

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 基金代码，支持多只基金，逗号分隔 |
| ann_date | str | N | 公告日期，格式：YYYYMMDD |
| name | str | N | 基金经理姓名 |
| offset | intint | N | 开始行数 |
| limit | int | N | 每页行数 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 基金代码 |
| ann_date | str | Y | 公告日期 |
| name | str | Y | 基金经理姓名 |
| gender | str | Y | 性别 |
| birth_year | str | Y | 出生年份 |
| edu | str | Y | 学历 |
| nationality | str | Y | 国籍 |
| begin_date | str | Y | 任职日期 |
| end_date | str | Y | 离任日期 |
| resume | str | Y | 简历 |

代码示例

```python
#初始接口
pro = ts.pro_api()

#单只基金
df = pro.fund_manager(ts_code='150018.SZ')

#多只基金
df = pro.fund_manager(ts_code='150018.SZ,150008.SZ')
```

数据示例

```python
ts_code  ann_date   name  gender birth_year edu nationality begin_date  end_date                                             resume
0  150018.SZ  20100508   周毅      M       None  硕士          美国   20100507      None  CFA，硕士学位；毕业于北京大学，美国南卡罗莱纳大学，美国约翰霍普金斯大学。曾任美国普华永道...
```